@@ -65,19 +65,19 @@ class Merge:
         end = timer()
         logger.debug(f'Generated and added concepts in {end - start} seconds')
 
-    def _get_other_ids(self, record: Dict) -> Set[str]:
+    def _get_xrefs(self, record: Dict) -> Set[str]:
         """Extract references to entries in other sources from a record.
         Crucially, filter to allowed sources only.
 
         :param Dict record: record to process
-        :return: Set of other_identifier values
+        :return: Set of xref values
         :rtype: Set
         """
-        other_ids = set()
-        for other_id in record.get('other_identifiers', []):
-            if other_id.split(':')[0] not in PROHIBITED_SOURCES:
-                other_ids.add(other_id)
-        return other_ids
+        xrefs = set()
+        for xref in record.get('xrefs', []):
+            if xref.split(':')[0] not in PROHIBITED_SOURCES:
+                xrefs.add(xref)
+        return xrefs
 
     def _create_record_id_set(self, record_id: str,
                               observed_id_set: Set = set()) -> Set[str]:
@@ -111,7 +111,7 @@ class Merge:
                                    f"{observed_id_set}")
                     return observed_id_set - {record_id}
 
-            local_id_set = self._get_other_ids(db_record)
+            local_id_set = self._get_xrefs(db_record)
             if not local_id_set:
                 return observed_id_set | {db_record['concept_id']}
             merged_id_set = {record_id} | observed_id_set
@@ -126,9 +126,9 @@ class Merge:
         scalars, assign from the highest-priority source where that attribute
         is non-null.
 
-        Priority is RxNorm > NCIt > ChemIDplus > Wikidata. ChEMBL and DrugBank
-        identifiers should not be included in record_id_set; doing so will
-        cause problems.
+        Priority is:
+        RxNorm > NCIt > HemOnc.org > DrugBank > ChemIDplus > Wikidata
+        ChEMBL records shouldn't be included in `record_id_set`.
 
         :param Set record_id_set: group of concept IDs
         :return: completed merged drug object to be stored in DB
@@ -159,28 +159,41 @@ class Merge:
             'label': None,
             'aliases': set(),
             'trade_names': set(),
-            'xrefs': set()
+            'associated_with': set(),
+            'approval_status': None,
+            'approval_year': set(),
+            'fda_indication': [],
         }
         if len(records) > 1:
-            merged_attrs['other_ids'] = [r['concept_id'] for r in records[1:]]
+            merged_attrs['xrefs'] = [r['concept_id'] for r in records[1:]]
 
         # merge from constituent records
-        set_fields = ['aliases', 'trade_names', 'xrefs']
+        set_fields = ['aliases', 'trade_names', 'associated_with',
+                      'approval_year']
         for record in records:
             for field in set_fields:
-                merged_attrs[field] |= set(record.get(field, {}))
+                merged_attrs[field] |= set(record.get(field, set()))
+            chembl_ids = {i for i in record.get('xrefs', [])
+                          if i.startswith('chembl')}
+            merged_attrs['associated_with'] |= chembl_ids
             if merged_attrs['label'] is None:
                 merged_attrs['label'] = record.get('label')
+            if merged_attrs['approval_status'] is None:
+                merged_attrs['approval_status'] = record.get('approval_status')
+            for ind in record.get('fda_indication', []):
+                if ind not in merged_attrs['fda_indication']:
+                    merged_attrs['fda_indication'].append(ind)
 
         # clear unused fields
-        for field in set_fields:
+        for field in set_fields + ['fda_indication']:
             field_value = merged_attrs[field]
             if field_value:
                 merged_attrs[field] = list(field_value)
             else:
                 del merged_attrs[field]
-        if merged_attrs['label'] is None:
-            del merged_attrs['label']
+        for field in ['label', 'approval_status']:
+            if merged_attrs[field] is None:
+                del merged_attrs[field]
 
         merged_attrs['label_and_type'] = \
             f'{merged_attrs["concept_id"].lower()}##merger'
